{ config, pkgs, ... }:

{
  imports =
    [
      <nixos-hardware/framework>
      ./hardware-configuration.nix
      <home-manager/nixos>
      ./user-packages.nix
      ./users.nix
      ./audio.nix
      ./system-packages.nix
      ./hibernation.nix
      ./bootloader.nix
      ./desktop-environment.nix
    ];

  # Setup keyfile
  boot.initrd.secrets = {
    "/crypto_keyfile.bin" = null;
  };

  networking.hostName = "Zenith-nixos"; # Define your hostname.

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Amsterdam";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_GB.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "nl_NL.UTF-8";
    LC_IDENTIFICATION = "nl_NL.UTF-8";
    LC_MEASUREMENT = "nl_NL.UTF-8";
    LC_MONETARY = "nl_NL.UTF-8";
    LC_NAME = "nl_NL.UTF-8";
    LC_NUMERIC = "nl_NL.UTF-8";
    LC_PAPER = "nl_NL.UTF-8";
    LC_TELEPHONE = "nl_NL.UTF-8";
    LC_TIME = "nl_NL.UTF-8";
  };

  # Enable CUPS to print documents.
  services.printing.enable = true;

  fonts.fontDir.enable = true;
  fonts.fonts = with pkgs; [
    roboto
    noto-fonts
  ];

  system.stateVersion = "23.05";
}
